summaryrefslogtreecommitdiffstats
path: root/extra/kde352/kkeyserver_x11.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-03 22:23:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-03 22:23:44 -0600
commit203ba231d0276943aae36111f9ec1e949f3c6a4c (patch)
treef039f7a5b5fc2da88a96876971bac580d87f6788 /extra/kde352/kkeyserver_x11.h
parentfd35f4a8382b7d223bc0325b9ca3f88515778aa0 (diff)
downloadpytde-203ba231d0276943aae36111f9ec1e949f3c6a4c.tar.gz
pytde-203ba231d0276943aae36111f9ec1e949f3c6a4c.zip
Initial TQt conversion
Diffstat (limited to 'extra/kde352/kkeyserver_x11.h')
-rw-r--r--extra/kde352/kkeyserver_x11.h106
1 files changed, 53 insertions, 53 deletions
diff --git a/extra/kde352/kkeyserver_x11.h b/extra/kde352/kkeyserver_x11.h
index b0a9766..d03553b 100644
--- a/extra/kde352/kkeyserver_x11.h
+++ b/extra/kde352/kkeyserver_x11.h
@@ -64,16 +64,16 @@ namespace KKeyServer
* @param s the description of the symbol
* @see toString()
*/
- Sym( const QString& s )
+ Sym( const TQString& s )
{ init( s ); }
/**
* Initializes the symbol with the given Qt key code.
* @param keyQt the qt key code
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
- bool initQt( int keyQt );
+ bool initTQt( int keyTQt );
/**
* Initializes the key with the given string description.
@@ -81,7 +81,7 @@ namespace KKeyServer
* @return true if successful, false otherwise
* @see toString()
*/
- bool init( const QString &s );
+ bool init( const TQString &s );
/**
* Returns the qt key code of the symbol.
@@ -92,22 +92,22 @@ namespace KKeyServer
/**
* @internal
*/
- QString toStringInternal() const;
+ TQString toStringInternal() const;
/**
* Returns the string representation of the symbol.
* @return the string representation of the symbol
*/
- QString toString() const;
+ TQString toString() const;
/**
* Returns the mods that are required for this symbol as
* ORed KKey::ModFlag's. For example, Break requires a
* Ctrl to be valid.
* @return the required KKey::ModFlag's
* @see KKey::ModFlag
*/
- uint getModsRequired() const;
+ uint getModsRetquired() const;
/**
* TODO: please find out what this method does and document it
@@ -125,9 +125,9 @@ namespace KKeyServer
Sym& operator =( uint sym ) { m_sym = sym; return *this; }
private:
- QString toString( bool bUserSpace ) const;
+ TQString toString( bool bUserSpace ) const;
- static void capitalizeKeyname( QString& );
+ static void capitalizeKeyname( TQString& );
};
/**
@@ -136,7 +136,7 @@ namespace KKeyServer
*/
struct TDECORE_EXPORT Key
{
/// Code for native Keys in Qt
enum { CODE_FOR_QT = 256 };
/// The code of the key
@@ -151,18 +151,18 @@ namespace KKeyServer
/**
* Initializes the key with a KKey.
* @param key the key to get the data from
* @param bQt true to take the Qt keycode, false
* for the native key code
- * @see Qt::Key
+ * @see TQt::Key
* @see KKeyNative
*/
- bool init( const KKey& key, bool bQt );
+ bool init( const KKey& key, bool bTQt );
/**
* Checks whether the key code is a native code.
* @return true if native code of the window system,
* false if it is a Qt keycode
* @see Qt::Key
* @see KKeyNative
*/
bool isNative() const { return m_code != CODE_FOR_QT; }
@@ -189,14 +189,14 @@ namespace KKeyServer
* Returns the qt key code.
* @return the qt key code
*/
- int keyCodeQt() const { return (int) m_sym; }
+ int keyCodeTQt() const { return (int) m_sym; }
/**
* Sets the qt key code.
* @param keyQt the qt key code
*/
- void setKeycodeQt( int keyQt )
- { m_code = CODE_FOR_QT; m_sym = keyQt; }
+ void setKeycodeTQt( int keyTQt )
+ { m_code = CODE_FOR_QT; m_sym = keyTQt; }
/**
* Initializes this key with a KKeyNative.
@@ -250,7 +250,7 @@ namespace KKeyServer
Variations() { m_nVariations = 0; }
- void init( const KKey&, bool bQt );
+ void init( const KKey&, bool bTQt );
uint count() const { return m_nVariations; }
const Key& key( uint i ) const { return m_rgkey[i]; }
@@ -346,47 +346,47 @@ namespace KKeyServer
TDECORE_EXPORT uint accelModMaskX();
/**
* Extracts the symbol from the given Qt key and
* converts it to a symbol.
* @param keyQt the qt key code
* @param sym if successful, the symbol will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
- TDECORE_EXPORT bool keyQtToSym( int keyQt, uint& sym );
+ TDECORE_EXPORT bool keyTQtToSym( int keyTQt, uint& sym );
/**
* Extracts the modifiers from the given Qt key and
* converts them in a mask of ORed KKey::ModFlag modifiers.
* @param keyQt the qt key code
* @param mod if successful, the modifiers will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
- TDECORE_EXPORT bool keyQtToMod( int keyQt, uint& mod );
+ TDECORE_EXPORT bool keyTQtToMod( int keyTQt, uint& mod );
/**
* Converts the given symbol to a Qt key code.
* @param sym the symbol
* @param keyQt if successful, the qt key code will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
- TDECORE_EXPORT bool symToKeyQt( uint sym, int& keyQt );
+ TDECORE_EXPORT bool symToKeyTQt( uint sym, int& keyTQt );
/**
* Converts the mask of ORed KKey::ModFlag modifiers to
* a mask of ORed Qt key code modifiers.
* @param mod the mask of KKey::ModFlag modifiers
* @param modQt the mask of Qt key code modifiers will be written here,
* if successful
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see KKey
*/
- TDECORE_EXPORT bool modToModQt( uint mod, int& modQt );
+ TDECORE_EXPORT bool modToModTQt( uint mod, int& modTQt );
/**
* Converts the mask of ORed KKey::ModFlag modifiers to
@@ -401,20 +401,20 @@ namespace KKeyServer
/**
* Converts the mask of ORed X11 modifiers to
* a mask of ORed Qt key code modifiers.
* @param modX the mask of X11 modifiers
* @param modQt the mask of Qt key code modifiers will be written here
* if successful
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
*/
//wrapped for win32
- TDECORE_EXPORT bool modXToModQt( uint modX, int& modQt );
+ TDECORE_EXPORT bool modXToModTQt( uint modX, int& modTQt );
/**
* Converts the Qt-compatible button state to x11 modifier.
*/
- TDECORE_EXPORT int qtButtonStateToMod( Qt::ButtonState s );
+ TDECORE_EXPORT int qtButtonStateToMod( TQt::ButtonState s );
/**
* Converts the mask of ORed X11 modifiers to
@@ -435,7 +435,7 @@ namespace KKeyServer
* @param modX the mask of ORed X11 modifiers
* @param symX if successful, the X11 symbol will be written here
* @return true if successful, false otherwise
- * @see Qt::Key
+ * @see TQt::Key
* @see Sym
*/
TDECORE_EXPORT bool codeXToSym( uchar codeX, uint modX, uint& symX );
@@ -443,7 +443,7 @@ namespace KKeyServer
/**
* @internal
*/
- TDECORE_EXPORT QString modToStringInternal( uint mod );
+ TDECORE_EXPORT TQString modToStringInternal( uint mod );
/**
* Converts the mask of ORed KKey::ModFlag modifiers to a
@@ -451,7 +451,7 @@ namespace KKeyServer
* @param mod the mask of ORed KKey::ModFlag modifiers
* @return the user-readable string
*/
- TDECORE_EXPORT QString modToStringUser( uint mod );
+ TDECORE_EXPORT TQString modToStringUser( uint mod );
/**
* Converts the modifier given as user-readable string
@@ -459,19 +459,19 @@ namespace KKeyServer
* @internal
* @since 3.5
*/
- TDECORE_EXPORT uint stringUserToMod( const QString& mod );
+ TDECORE_EXPORT uint stringUserToMod( const TQString& mod );
/**
* @internal
* Unimplemented?
*/
- TDECORE_EXPORT bool stringToSymMod( const QString&, uint& sym, uint& mod );
+ TDECORE_EXPORT bool stringToSymMod( const TQString&, uint& sym, uint& mod );
/**
* @internal
* Unimplemented?
*/
- TDECORE_EXPORT void keyQtToKeyX( uint keyCombQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
+ TDECORE_EXPORT void keyTQtToKeyX( uint keyCombTQt, unsigned char *pKeyCodeX, uint *pKeySymX, uint *pKeyModX );
}
#endif // !_KKEYSERVER_X11_H
@@ -64,16 +64,16 @@ namespace KKeyServer
{ init( s ); }
/**
- * Initializes the symbol with the given Qt key code.
- * @param keyQt the qt key code
+ * Initializes the symbol with the given TQt key code.
+ * @param keyTQt the qt key code
* @return true if successful, false otherwise
@@ -92,22 +92,22 @@ namespace KKeyServer
/**
- * Returns the mods that are required for this symbol as
- * ORed KKey::ModFlag's. For example, Break requires a
+ * Returns the mods that are retquired for this symbol as
+ * ORed KKey::ModFlag's. For example, Break retquires a
* Ctrl to be valid.
@@ -92,22 +92,22 @@ namespace KKeyServer
* Ctrl to be valid.
- * @return the required KKey::ModFlag's
+ * @return the retquired KKey::ModFlag's
* @see KKey::ModFlag
*/
@@ -136,7 +136,7 @@ namespace KKeyServer
struct TDECORE_EXPORT Key
{
- /// Code for native Keys in Qt
+ /// Code for native Keys in TQt
enum { CODE_FOR_QT = 256 };
/// The code of the key
@@ -151,18 +151,18 @@ namespace KKeyServer
* Initializes the key with a KKey.
* @param key the key to get the data from
- * @param bQt true to take the Qt keycode, false
+ * @param bTQt true to take the TQt keycode, false
* for the native key code
@@ -151,18 +151,18 @@ namespace KKeyServer
* Checks whether the key code is a native code.
* @return true if native code of the window system,
- * false if it is a Qt keycode
- * @see Qt::Key
+ * false if it is a TQt keycode
+ * @see TQt::Key
* @see KKeyNative
*/
@@ -189,14 +189,14 @@ namespace KKeyServer
/**
* Sets the qt key code.
- * @param keyQt the qt key code
+ * @param keyTQt the qt key code
*/
@@ -346,47 +346,47 @@ namespace KKeyServer
TDECORE_EXPORT uint accelModMaskX();
/**
- * Extracts the symbol from the given Qt key and
+ * Extracts the symbol from the given TQt key and
* converts it to a symbol.
@@ -346,47 +346,47 @@ namespace KKeyServer
* converts it to a symbol.
- * @param keyQt the qt key code
+ * @param keyTQt the qt key code
* @param sym if successful, the symbol will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
/**
- * Extracts the modifiers from the given Qt key and
+ * Extracts the modifiers from the given TQt key and
* converts them in a mask of ORed KKey::ModFlag modifiers.
@@ -346,47 +346,47 @@ namespace KKeyServer
* converts them in a mask of ORed KKey::ModFlag modifiers.
- * @param keyQt the qt key code
+ * @param keyTQt the qt key code
* @param mod if successful, the modifiers will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
/**
- * Converts the given symbol to a Qt key code.
+ * Converts the given symbol to a TQt key code.
* @param sym the symbol
@@ -346,47 +346,47 @@ namespace KKeyServer
* @param sym the symbol
- * @param keyQt if successful, the qt key code will be written here
+ * @param keyTQt if successful, the qt key code will be written here
* @return true if successful, false otherwise
@@ -346,47 +346,47 @@ namespace KKeyServer
/**
* Converts the mask of ORed KKey::ModFlag modifiers to
- * a mask of ORed Qt key code modifiers.
+ * a mask of ORed TQt key code modifiers.
* @param mod the mask of KKey::ModFlag modifiers
@@ -346,47 +346,47 @@ namespace KKeyServer
* @param mod the mask of KKey::ModFlag modifiers
- * @param modQt the mask of Qt key code modifiers will be written here,
+ * @param modTQt the mask of TQt key code modifiers will be written here,
* if successful
* @return true if successful, false otherwise
@@ -401,20 +401,20 @@ namespace KKeyServer
/**
* Converts the mask of ORed X11 modifiers to
- * a mask of ORed Qt key code modifiers.
+ * a mask of ORed TQt key code modifiers.
* @param modX the mask of X11 modifiers
@@ -401,20 +401,20 @@ namespace KKeyServer
* @param modX the mask of X11 modifiers
- * @param modQt the mask of Qt key code modifiers will be written here
+ * @param modTQt the mask of TQt key code modifiers will be written here
* if successful
* @return true if successful, false otherwise
@@ -401,20 +401,20 @@ namespace KKeyServer
/**
- * Converts the Qt-compatible button state to x11 modifier.
+ * Converts the TQt-compatible button state to x11 modifier.
*/